@@ -1,7 +1,8 @@
-from kh_common.utilities import getFullyQualifiedClassName
+from kh_common.exceptions.http_error import BadGateway
 from kh_common.exceptions.base_error import BaseError
 from kh_common.logging import getLogger, Logger
 from fastapi.responses import UJSONResponse
+from aiohttp import ClientError
 from typing import Dict, Union
 from fastapi import Request
 from uuid import uuid4
@@ -21,6 +22,11 @@ def jsonErrorHandler(request: Request, e: Exception) -> UJSONResponse :
 	if isinstance(e, BaseError) :
 		error['error'] = f'{e.__class__.__name__}: {e}'
 
+	elif isinstance(e, ClientError) :
+		error['error'] = f'{BadGateway.__name__}: received an invalid response from an upstream server.'
+		status = error['status'] = BadGateway.status
+		logger.error(error, exc_info=e)
+
 	else :
 		logger.error(error, exc_info=e)
 		error['error'] = 'Internal Server Error'
